// This file contains a small library of JavaScript functions used
// by the Hscript-JavaScript cookbook.

// This class contains information about a pane.
function OHBPaneInfo(name, type)
{
    this.name = name;
    this.type = type;
}

function HBgetPanes()
{
    var result = new Array();
    var panes_string = RunHCommand("pane");

    // If you're testing from a real Mozilla browser and Houdini isn't running,
    // an empty string will be returned.
    if (!panes_string.length)
	return result;

    var panes_array = panes_string.split("\n");
    var re = /([A-Za-z0-9]*) -m ([A-Za-z0-9 ]*)/;
    var pane_name, pane_type;

    for (pane_index in panes_array)
    {
	pane_name = panes_array[pane_index].replace(re, "$1");
	pane_type = panes_array[pane_index].replace(re, "$2");
	result[pane_index] = new OHBPaneInfo(pane_name, pane_type);
    }

    return result;
}

function HBFindPaneName(pane_type)
{
    var panes = HBgetPanes();
    var pane_index;

    for (pane_index in panes)
    {
	if (panes[pane_index].type == pane_type)
	    return panes[pane_index].name;
    }

    return null;
}

function HBcommandLineSwitchValue(command_line, switch_name)
{
    // Returns the value of the switch (as a string), if set, or null
    // if it is not found.
    var re = new RegExp(switch_name + " +([a-zA-Z0-9]*)");
    var matched;

    matched = command_line.match(re);
    if (matched == null)
	return null;

    return matched[1];
}

function HBonoff2bool(onoff_value)
{
    if (onoff_value == "on")
	return true;
    if (onoff_value == "off")
	return false;
    return null;
}

function HBbool2onoff(bool_value)
{
    if (bool_value)
	return "on";
    return "off";
}

function HBfirstWord(line)
{
    var match = line.matchline.match(/^[^ ]*/);
    if (match == null)
	return null;

    return match.toString();
}

function HBgetURLDirectory()
{
    var dirname_re = new RegExp("(.*\/)[^/]*");
    var file_prefix_re = new RegExp("^file://(.*)");
    var drive_re = new RegExp("^/([a-zA-Z]:[^0-9].*)");
    var match = location.href.match(dirname_re);
    var dirname = match[1];
    var result;

    // If the URL starts with http://, don't strip the http:// part.
    match = dirname.match(file_prefix_re);
    if (match == null)
	return dirname;

    // Strip the file:// part.
    result = match[1];

    // Make sure there isn't a slash before the drive letter.
    match = result.match(drive_re);
    if (match == null)
	return result;

    // Strip the / before the drive letter.
    return match[1];
}

